Account
=======

You can edit your account in the Account page.  You can change your real name,
e-mail and password.  You can also set the preferences.

Some sites require you contact an administrator to change your details.
In this case, the Account page allows you to generate a hash to let your
password be changed securely (your administrator cannot recover the password
from the hash).

.. warning::

   The real name is not changed on the posts already created.

.. note::

   If you want to change your username, you must contact an administrator.


.. admonition:: Permissions

   In order to enable the “Show me posts by other users by default” preference, you must
   first have the “can edit others’ posts” permission.
